[![Build status](https://travis-ci.org/kutaslab/fitgrid.svg?branch=master)](https://travis-ci.org/kutaslab/fitgrid)
[![Coverage](https://codecov.io/gh/kutaslab/fitgrid/branch/master/graph/badge.svg)](https://codecov.io/gh/kutaslab/fitgrid)
[![DOI](https://zenodo.org/badge/147436563.svg)](https://zenodo.org/badge/latestdoi/147436563)

# fitgrid

A Python library for modeling time-varying patterns of activity in sensor-array data streams on a 2-D grid.

## Documentation

Available [here](https://kutaslab.github.io/fitgrid).


## Recommended for full installation

    conda install -c kutaslab fitgrid

Alternatively, with no `lmer` support,

    pip3 install fitgrid


## Demo

Click this button to launch a demo notebook:

[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/kutaslab/fitgrid/master?filepath=notebooks/Demo.ipynb)
